import {
  ArgumentsHost,
  Catch,
  ExceptionFilter,
  Injectable,
} from '@nestjs/common';
import { Response } from 'express';
import { IRequest } from '@/interface';
import { BaseError } from '@/common/exception/BaseError';

@Injectable()
@Catch()
export class ApiExceptionsFilter implements ExceptionFilter {
  catch(exception: any, host: ArgumentsHost) {
    const ctx = host.switchToHttp();
    const response = ctx.getResponse<Response>();
    const req = ctx.getRequest<IRequest>();

    if (exception instanceof BaseError) {
      const json = exception.toJson();
      return response.status(200).json({
        code: json.code,
        message: json.message,
        requestId: req.requestId,
      });
    }

    // 未知错误，触发错误报警
    console.error('请求 HOST：' + req?.hostname);
    console.error('请求路径：' + JSON.stringify(req?.path));
    console.error('请求参数 QUERY:' + JSON.stringify(req?.query));
    console.error('请求参数 BODY:' + JSON.stringify(req?.body));

    console.error('\n***\n', '未知错误', exception);
    const status = exception?.status || exception?.statusCode || 500;

    console.error('requestId:' + req.requestId);
    const errorMessage = exception?.response?.message ?? exception.message;

    console.error(
      'errorMessage:' + errorMessage
        ? errorMessage
        : JSON.parse(exception.message),
    );

    return response.status(200).json({
      code: status,
      message: errorMessage ? errorMessage : JSON.parse(exception.message),
      requestId: req.requestId,
    });
  }
}
