import { axiosGetRequest, axiosPostRequest } from './request';
import { config } from '../../../config';
import * as qs from 'qs';
import { BadRequestException, UnauthorizedException } from '@nestjs/common';

const host = config.server;

export async function commonGetJsonRequest(
  userToken: string,
  url: string,
  sp: Record<string, any>,
  options?: {
    headers?: Record<string, any>;
  },
) {
  const endpoint = new URL(host + url);

  const { data } = await axiosGetRequest(
    endpoint.toString() + '?' + qs.stringify(sp),
    {
      headers: {
        Accept: 'application/json',
        Authorization: userToken,
        ...options?.headers,
      },
    },
  );
  if (typeof data !== 'object') {
    throw new BadRequestException({
      statusCode: 400,
      message: `API 返回值不是 JSON 格式，实际格式为 ${typeof data}`,
    });
  }

  if (data?.statusCode !== 200 && data?.code !== 200) {
    if (data?.statusCode === 401) {
      throw new UnauthorizedException({
        statusCode: 401,
        message: '未授权请求',
      });
    }
    throw new BadRequestException({
      statusCode: data?.statusCode || 400,
      message: data?.message,
    });
  }

  return data;
}

export async function commonPostJsonRequest(
  userToken: string,
  url: string,
  params: Record<string, any>,
  options?: {
    headers?: Record<string, any>;
  },
) {
  const { data } = await axiosPostRequest(host + url, params, {
    headers: {
      Accept: 'application/json',
      Authorization: userToken,
      ...options?.headers,
    },
  });

  if (typeof data !== 'object') {
    throw new BadRequestException({
      statusCode: 400,
      message: `API 返回值不是 JSON 格式，实际格式为 ${typeof data}`,
    });
  }

  if (data?.statusCode !== 200 && data?.code !== 200) {
    if (data?.statusCode === 401) {
      throw new UnauthorizedException({
        statusCode: 401,
        message: '未授权请求',
      });
    }
    throw new BadRequestException({
      statusCode: data?.statusCode || 400,
      message: data?.message,
    });
  }

  return data;
}
