import { env } from './env';

/**
 * 应用配置
 */
interface AppConfig {
  /**
   *  环境变量
   */
  env: string;

  /** 应用启动端口 */
  port: number;

  // api 域名
  server: string;

  // 一级域名
  domain: string;

  // json limit size
  jsonLimit: string;

  cors: {
    origin: string[];
  };

  session: {
    secret: string;
  };

  jwt: {
    secret: string;
    expiresIn: string;
  };

  rsaSecret: {
    /** 应用公钥 */
    publicKey: string;

    /** 应用私钥 */
    privateKey: string;
  };

  obs: {
    endpoint: string;
  };
}

const server = env.APP_SERVER ?? 'http://localhost:3000';

const cors = process.env?.APP_CORS?.split(',');

export const app: AppConfig = {
  domain: env.APP_DOMAIN ?? 'https://localhost:3000',
  env: env.APP_ENV ?? 'prod',
  port: Number(env.APP_PORT ?? 3000),
  server,
  jsonLimit: env.APP__JSON_LIMIT ?? '50mb',

  cors: {
    origin: cors ?? [],
  },

  session: {
    secret: env.APP_SESSION_SECRET ?? 'session',
  },

  jwt: {
    secret: env.APP_JWT_SECRET ?? 'secret',
    expiresIn: env.APP_JWT_EXPIRES_IN ?? '1d',
  },

  rsaSecret: {
    publicKey: env.APP_RSA_PUBLIC_KEY ?? '',
    privateKey: env.APP_RSA_PRIVATE_KEY ?? '',
  },

  obs: {
    endpoint: env.APP_OBS_ENDPOINT ?? 'https://resources.laihua.com',
  },
};
