import { env } from './env';
import { RedisClientOptions } from 'redis';
import { ServerError } from '@/common/exception/ServerError';

export type SUPPORTED_CACHE_STORAGE_TYPE = 'lru' | 'redis';

export interface RedisConfig {
  url: string;

  /**
   * 是否开启集群模式
   */
  clusterEnabled: boolean;

  /** Redis 配置项 */
  options: RedisClientOptions;
}

/**
 * 缓存配置
 */
export interface CacheConfig {
  /** 缓存驱动类型 */
  type: SUPPORTED_CACHE_STORAGE_TYPE;

  /** Redis 配置项 */
  redis: RedisConfig;
}

export const cache: CacheConfig = {
  type: 'redis',

  redis: {
    url: env.APP_CACHE_URL ?? 'localhost/6379',
    clusterEnabled: Boolean(env.APP_CACHE_CLUSTER_ENABLED ?? false),
    options: JSON.parse(env.APP_CACHE_OPTIONS ?? '{}'),
  },
};

if (!cache.redis.clusterEnabled && !cache.redis.url) {
  throw ServerError.default('配置文件缺少 redis url 配置');
}
