import { env } from './env';
/** 连接数配置 */
export interface ConnectionPoolConfig {
  max: number; // 最大连接数
  min: number; // 最小连接数
  idleTimeoutMillis: number; // 空闲回收时间
}
export interface DatabaseConfig {
  type: 'mysql';
  database?: string;
  url?: string;

  synchronize: boolean;
  pool: ConnectionPoolConfig;
  logging: 'error' | 'warn' | 'log' | 'migration';
  maxQueryExecutionTime?: number;
  supportBigNumbers: boolean;
  bigNumberStrings: boolean;
}

export const database: DatabaseConfig = {
  type: (env.APP_DATABASE_TYPE as any) ?? 'sqlite',
  database: env.APP_DATABASE_DATABASE ?? './database.sqlite',
  url: env.APP_DATABASE_URL,
  synchronize: Boolean(env.APP_DATABASE_SYNCHRONIZE ?? false),

  pool: {
    max: Number(env.APP_DATABASE_POOL_MAX ?? 32),
    min: Number(env.APP_DATABASE_POOL_MIN ?? 16),
    idleTimeoutMillis: Number(
      env.APP_DATABASE_POOL_IDLE_TIMEOUT_MILLIS ?? 20000,
    ),
  },
  maxQueryExecutionTime: Number(
    env.APP_DATABASE_MAX_QUERY_EXECUTION_TIME ?? 200,
  ), // 单位为毫秒
  logging: (env.APP_DATABASE_LOGGING as any) ?? 'error',
  bigNumberStrings: Boolean(env.APP_DATABASE_BIG_NUMBER_STRINGS ?? false),
  supportBigNumbers: Boolean(env.APP_DATABASE_SUPPORT_BIG_NUMBERS ?? true),
};
