import { ApiProperty } from '@nestjs/swagger';
import { Expose } from 'class-transformer';
import { IsNotEmpty, IsNumber, IsOptional, IsString } from 'class-validator';

export class TextToSpeechReqDto {
  @ApiProperty({
    description: '要转换为语音的文本',
    type: String,
    example: '要转换为语音的文本',
  })
  @Expose()
  @IsNotEmpty()
  @IsString()
  text: string;

  @ApiProperty({
    description: '语音发音人Id',
    type: String,
    example: 'uuid',
  })
  @Expose()
  @IsNotEmpty()
  @IsString()
  speaker: string;

  @ApiProperty({
    description: '语音速度',
    type: Number,
    required: false,
    default: 5,
    example: 5,
  })
  @Expose()
  @IsOptional()
  @IsNumber()
  speed?: number = 5;
}
