import { SupportLanguages } from '@/common/utils/constants';
import { ApiProperty } from '@nestjs/swagger';
import { Expose } from 'class-transformer';
import { IsEnum, IsNotEmpty, IsString } from 'class-validator';

export class TranslateReqDto {
  @ApiProperty({
    description: '目标语言',
    enum: SupportLanguages,
    example: SupportLanguages.AR,
  })
  @Expose()
  @IsNotEmpty()
  @IsEnum(SupportLanguages)
  target: SupportLanguages;

  @ApiProperty({
    description: '源语言',
    enum: SupportLanguages,
    example: SupportLanguages.EN,
  })
  @Expose()
  @IsNotEmpty()
  @IsEnum(SupportLanguages)
  source: SupportLanguages;

  @ApiProperty({
    description: '待翻译文本',
    type: String,
    example: '待翻译文本',
  })
  @Expose()
  @IsNotEmpty()
  @IsString()
  text: string;
}
