import { UserEntity } from '@/entities/user.entity';
import * as express from 'express';

// JSON 类型递归定义
type JSONValue =
  | string
  | number
  | boolean
  | { [x: string]: JSONValue }
  | Array<JSONValue>;

export enum Lang {
  zhCn = 'zh-CN',
  enUs = 'en-US',
  zhTw = 'zh-TW',
  jaJP = 'ja-JP',
}

export enum Status {
  true = 1,
  false = 0,
}

export interface IRequest extends express.Request {
  /** 二级域名 */
  subDomain: string;

  /** 请求 ID */
  requestId: string;

  /** 是否为 graphql 请求 */
  isGraphqlRequest: boolean;

  /** 请求主体唯一标志符 */
  operatorArn: string;

  /** 请求主体类型 */
  operatorType: 'user' | 'role';

  /** 请求主体 ID，有可能是用户 ID 或者角色 ID，需要通过 operatorType 判断 */
  operatorId: string;

  /** 传递给访问日志中间件的原始异常对象 */
  rawErrorObject: any;

  userAgent: string;
  loggedIn: boolean;

  user: UserEntity;

  clientIp: string;
  device: string;
  os: string;
  octetString: string;
  token: string;
  decodedToken: DecodedToken;

  lang: Lang;

  /** 请求完整链接，包含 protocol, query */
  fullUrl: string;
  /** 当前请求的二级域名，如 https://xxxx.baidu.com */
  hostWithProtocol: string;
}

export interface DecodedToken {
  aud: string;
  jti: string;
  name?: string;
  phone?: string;
  email?: string;
  sub: string;
  given_name?: string;
  family_name?: string;
  middle_name?: string;
  nickname?: string;
  preferred_username?: string;
  profile?: string;
  picture?: string;
  website?: string;
  email_verified?: boolean;
  gender?: string;
  username?: string;
  locale?: string;
  phone_number?: string;
  phone_number_verified?: boolean;
  address?: JSONValue;
  exp: number;
}

export type KeyValuePair = Record<string, any>;
