import { NestFactory } from '@nestjs/core';
import { AppModule } from './app.module';
import { IRequest } from './interface';
import { Response } from 'express';
import * as onHeaders from 'on-headers';
import { setupOpenApi } from './openapi';
import { NestExpressApplication } from '@nestjs/platform-express';
import { config } from './config';
import { ValidationPipe } from '@nestjs/common';

async function bootstrap() {
  const app = await NestFactory.create<NestExpressApplication>(AppModule, {
    rawBody: true,
  });

  app.enableCors({
    credentials: true,
    origin: config.cors.origin,
    maxAge: 604800,
  });

  app.useGlobalPipes(new ValidationPipe());

  app.use((req: IRequest, res: Response, next) => {
    onHeaders(res, () => {
      res.setHeader('Cache-Control', 'no-cache');
    });
    next();
  });

  setupOpenApi(app);

  await app.listen(config.port);

  console.log('Server Listen ' + config.port);
}
bootstrap();
