import { INestApplication } from '@nestjs/common';
import { DocumentBuilder, SwaggerModule } from '@nestjs/swagger';

export const setupOpenApi = (app: INestApplication) => {
  const builder = new DocumentBuilder()
    .setTitle('Translation API')
    .setDescription(
      'HTTP status code of 200 indicates a successful response, while any non-200 status code signifies an error response. Specifically, when the HTTP status code is 401, it means that the user is unauthenticated and needs to be redirected to the login page for authentication.',
    )
    .setVersion('1.0')
    .addBearerAuth();

  /**
   * openapi 展示
   */
  const document = SwaggerModule.createDocument(app, builder.build(), {
    include: [],
  });

  Object.assign(document.info, {
    'x-meta': {
      title: 'Translation Server API',
      description:
        'Translation starts with campus mutual aid and provides a platform for everyone to promote each other and grow together.',
      image: '',
    },
  });
  SwaggerModule.setup('openapi', app, document);
  console.log(`OpenAPI Swagger Start ! /openapi`);
};
